@@ -22,6 +22,7 @@ from urllib3 import disable_warnings
 from . import projections
 from . import enums
 from .globals import RequestClient, DefaultRequestClient
+from uuid import UUID
 import warnings
 
 import six
@@ -318,11 +319,12 @@ def do_request(service, params={F: JSON}, ret_json=True, token='', cookies=None,
 
     # auto fill in geometry params if a restapi.Geometry object is passed in (derived from BaseGeometry)
     if params.get(enums.params.geometry) and isinstance(params.get(enums.featureSet.geometry), BaseGeometry):
-        geometry = params.get(enums.params.geometry)
-        if not enums.geometry.type in params and hasattr(geometry, enums.geometry.type):
-            params[enums.geometry.type] = getattr(geometry, enums.geometry.type)
-        if not enums.params.inSR in params:
-            params[enums.params.inSR] = geometry.getWKID() or geometry.getWKT()
+        if not params.get(enums.params.geometries):
+            geometry = params.get(enums.params.geometry)
+            if not enums.geometry.type in params and hasattr(geometry, enums.geometry.type):
+                params[enums.geometry.type] = getattr(geometry, enums.geometry.type)
+            if not enums.params.inSR in params:
+                params[enums.params.inSR] = geometry.getWKID() or geometry.getWKT()
 
     for pName, p in six.iteritems(params):
         if isinstance(p, dict) or hasattr(p, 'json'):
@@ -1270,6 +1272,9 @@ class FeatureSet(FeatureSetBase):
             # print(self.json.keys())
             raise ValueError('Not a valid Feature Set!')
 
+        if self.features:
+            self.fixGUID()
+
     def extend(self, other):
         """Combines features from another FeatureSet with this one.
 
@@ -1303,6 +1308,27 @@ class FeatureSet(FeatureSetBase):
         return FeatureSet(fsd)
 
 
+    def fixGUID(self):
+        """Adds curly braces to GlobalID&GUID Values"""
+        fix_fields = [fld.name for fld in self.fields if fld.type in [GUID_FIELD, GLOBALID]]
+        if not fix_fields:
+            return
+        for feat in self.features:
+            for field in fix_fields:
+                try:
+                    globalid = feat[ATTRIBUTES][field]
+                    if not globalid:
+                        continue
+                    globalid = UUID(feat[ATTRIBUTES][field])
+                    feat[ATTRIBUTES][field] = '{{{}}}'.format(globalid)
+                except:
+                    warnings.warn('Invalid GUID value in field {}: {} (OID:{}) )'.format(
+                        field,
+                        feat[ATTRIBUTES][field],
+                        feat[ATTRIBUTES].get(self.OIDFieldName)
+                    ))
+
+
 class FeatureCollection(FeatureSetBase):
     """Class that handles Geo JSON formatted Feature Set, known as a FeatureCollection."""
     _format = GEOJSON_FORMAT
